@@ -5,11 +5,12 @@ except ImportError:
     from ConfigParser import SafeConfigParser as ConfigParser
 import io
 import logging
-import numpy.distutils.system_info as numpy_sys
-import numpy
 import os
+from shlex import split as shsplit
 import sys
 
+import numpy
+
 logger = logging.getLogger('pythran')
 
 
@@ -55,17 +56,22 @@ def get_paths_cfg(
                                             "pythran-default.cfg")
 
     user_config_path = os.environ.get('PYTHRANRC', None)
-    if not user_config_path:
+    if user_config_path is None:
         user_config_dir = os.environ.get('XDG_CONFIG_HOME', None)
         if not user_config_dir:
             user_config_dir = os.environ.get('HOME', None)
         if not user_config_dir:
             user_config_dir = '~'
-        user_config_path = os.path.expanduser(
-            os.path.join(user_config_dir, user_file))
-    return {"sys": sys_config_path,
-            "platform": platform_config_path,
-            "user": user_config_path}
+        user_config_path = os.path.expanduser(os.path.join(user_config_dir,
+                                                           user_file))
+
+    paths = {"sys": sys_config_path,
+             "platform": platform_config_path}
+
+    if user_config_path:
+        paths["user"] = user_config_path
+
+    return paths
 
 
 def init_cfg(sys_file, platform_file, user_file, config_args=None):
@@ -73,12 +79,14 @@ def init_cfg(sys_file, platform_file, user_file, config_args=None):
 
     sys_config_path = paths["sys"]
     platform_config_path = paths["platform"]
-    user_config_path = paths["user"]
+    user_config_path = paths.get("user")
 
     cfgp = ConfigParser()
     for required in (sys_config_path, platform_config_path):
         cfgp.read([required])
-    cfgp.read([user_config_path])
+
+    if user_config_path:
+        cfgp.read([user_config_path])
 
     if config_args is not None:
         update_cfg(cfgp, config_args)
@@ -152,10 +160,8 @@ def make_extension(python, **extra):
     cfg = init_cfg('pythran.cfg',
                    'pythran-{}.cfg'.format(sys.platform),
                    '.pythranrc',
-                   extra.get('config', None))
+                   extra.pop('config', None))
 
-    if 'config' in extra:
-        extra.pop('config')
 
     def parse_define(define):
         index = define.find('=')
@@ -168,19 +174,19 @@ def make_extension(python, **extra):
         "language": "c++",
         # forcing str conversion to handle Unicode case (the default on MS)
         "define_macros": [str(x) for x in
-                          cfg.get('compiler', 'defines').split()],
+                          shsplit(cfg.get('compiler', 'defines'))],
         "undef_macros": [str(x) for x in
-                         cfg.get('compiler', 'undefs').split()],
+                         shsplit(cfg.get('compiler', 'undefs'))],
         "include_dirs": [str(x) for x in
-                         cfg.get('compiler', 'include_dirs').split()],
+                         shsplit(cfg.get('compiler', 'include_dirs'))],
         "library_dirs": [str(x) for x in
-                         cfg.get('compiler', 'library_dirs').split()],
+                         shsplit(cfg.get('compiler', 'library_dirs'))],
         "libraries": [str(x) for x in
-                      cfg.get('compiler', 'libs').split()],
+                      shsplit(cfg.get('compiler', 'libs'))],
         "extra_compile_args": [str(x) for x in
-                               cfg.get('compiler', 'cflags').split()],
+                               shsplit(cfg.get('compiler', 'cflags'))],
         "extra_link_args": [str(x) for x in
-                            cfg.get('compiler', 'ldflags').split()],
+                            shsplit(cfg.get('compiler', 'ldflags'))],
         "extra_objects": []
     }
 
@@ -207,12 +213,12 @@ def make_extension(python, **extra):
     # standard environment variable is `CXXFLAGS` not `CFLAGS`).
     cflags = os.environ.get('CXXFLAGS', None)
     if cflags is not None:
-        extension['extra_compile_args'].extend(cflags.split())
+        extension['extra_compile_args'].extend(shsplit(cflags))
 
     # Honor LDFLAGS
     ldflags = os.environ.get('LDFLAGS', None)
     if ldflags is not None:
-        extension['extra_link_args'].extend(ldflags.split())
+        extension['extra_link_args'].extend(shsplit(ldflags))
 
     for k, w in extra.items():
         extension[k].extend(w)
@@ -239,23 +245,26 @@ def make_extension(python, **extra):
         except ImportError:
             logger.warning("Failed to find 'pythran-openblas' package. "
                            "Please install it or change the compiler.blas "
-                           "setting. Defaulting to 'blas'")
-            user_blas = 'blas'
-    elif user_blas == 'none':
+                           "setting. Defaulting to 'none'")
+            user_blas = 'none'
+
+    if user_blas == 'none':
         extension['define_macros'].append('PYTHRAN_BLAS_NONE')
 
     if user_blas not in reserved_blas_entries:
-        # Numpy can pollute stdout with checks
-        with silent():
-            numpy_blas = numpy_sys.get_info(user_blas)
-            # required to cope with atlas missing extern "C"
-            extension['define_macros'].append('PYTHRAN_BLAS_{}'
-                                              .format(user_blas.upper()))
-            extension['libraries'].extend(numpy_blas.get('libraries', []))
-            extension['library_dirs'].extend(
-                numpy_blas.get('library_dirs', []))
-            extension['include_dirs'].extend(
-                numpy_blas.get('include_dirs', []))
+        try:
+            import numpy.distutils.system_info as numpy_sys
+             # Numpy can pollute stdout with checks
+            with silent():
+                numpy_blas = numpy_sys.get_info(user_blas)
+                extension['libraries'].extend(numpy_blas.get('libraries', []))
+                extension['library_dirs'].extend(
+                    numpy_blas.get('library_dirs', []))
+        # `numpy.distutils` not present for Python >= 3.12
+        except ImportError:
+            blas = numpy.show_config('dicts')["Build Dependencies"]["blas"]
+            libblas = {'openblas64': 'openblas'}.get(blas['name'], blas['name'])
+            extension["libraries"].append(libblas)
 
 
     # final macro normalization
@@ -376,8 +385,12 @@ def run():
                        for include in extension['libraries'])
 
         if args.python:
-            ldflags.append(compiler_obj.library_dir_option(distutils.sysconfig.get_config_var('LIBPL')))
-            ldflags.extend(distutils.sysconfig.get_config_var('LIBS').split())
+            libpl = distutils.sysconfig.get_config_var('LIBPL')
+            if libpl:
+                ldflags.append(libpl)
+            libs = distutils.sysconfig.get_config_var('LIBS')
+            if libs:
+                ldflags.extend(shsplit(libs))
             ldflags.append(compiler_obj.library_option('python')
                            + distutils.sysconfig.get_config_var('VERSION'))
 
