@@ -52,9 +52,9 @@
 #include <ostream>
 
 #ifdef ENABLE_PYTHON_MODULE
-// Cython still uses the deprecated API, so we can't set this macro in this
-// case!
-#ifndef CYTHON_ABI
+// Cython 0.29.x still uses the deprecated API, so we can't set this macro in
+// this case! Also avoid redefining it if already set by the Pythran user.
+#if !defined(CYTHON_ABI) && !defined(NPY_NO_DEPRECATED_API)
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 #endif
 #include "numpy/arrayobject.h"
@@ -677,6 +677,10 @@ namespace types
     ndarray<T, pshape<long>> flat() const;
     ndarray<T, pS> copy() const;
     intptr_t id() const;
+    intptr_t baseid() const
+    {
+      return id();
+    }
     template <size_t I>
     auto shape() const -> decltype(std::get<I>(_shape))
     {
@@ -821,8 +825,8 @@ namespace builtins
     template <>
     struct _build_gexpr<1> {
       template <class E, class... S>
-      types::numpy_gexpr<E, types::normalize_t<S>...>
-      operator()(E const &a, S const &...slices);
+        auto
+      operator()(E const &a, S const &...slices) -> decltype(E(a)(slices...));
     };
 
     template <class E>
